@@ -1,18 +1,15 @@
-# -*- coding: utf-8 -*-
 """Image sequencing clip tests meant to be run with pytest."""
+
 import os
-import sys
 
 import pytest
 
 from moviepy.video.io.ImageSequenceClip import ImageSequenceClip
 
-from .test_helper import TMP_DIR
 
-
-def test_1():
-    images=[]
-    durations=[]
+def test_1(util):
+    images = []
+    durations = []
 
     for i in range(5):
         durations.append(i)
@@ -22,21 +19,24 @@ def test_1():
 
     with ImageSequenceClip(images, durations=durations) as clip:
         assert clip.duration == sum(durations)
-        clip.write_videofile(os.path.join(TMP_DIR, "ImageSequenceClip1.mp4"), fps=30)
+        clip.write_videofile(
+            os.path.join(util.TMP_DIR, "ImageSequenceClip1.mp4"), fps=30, logger=None
+        )
+
 
 def test_2():
-    images=[]
-    durations=[]
+    images = []
+    durations = []
 
     durations.append(1)
     images.append("media/python_logo.png")
     durations.append(2)
     images.append("media/matplotlib_demo1.png")
 
-    #images are not the same size..
+    # images are not the same size..
     with pytest.raises(Exception):
-         ImageSequenceClip(images, durations=durations).close()
+        ImageSequenceClip(images, durations=durations).close()
 
 
-if __name__ == '__main__':
-   pytest.main()
+if __name__ == "__main__":
+    pytest.main()
